Working on Betty’s translations - Betty 0.4.0a1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Working on Betty’s translations

## Making changes to the translatable strings in the source code

Run `betty update-translations` to update the translations files with the changes you made.

## Adding translations for a language for which no translations exist yet

Run `betty init-translation $locale` where `$locale` is an IETF BCP 47 language tag.